@@ -1,4 +1,4 @@
-# $Id: emoncms.py 1301 2015-04-18 14:43:33Z mwall $
+# $Id: emoncms.py 1343 2015-07-24 23:49:19Z mwall $
 # Copyright 2013-2014 Matthew Wall
 
 """
@@ -53,6 +53,7 @@ the input, independent of the local weewx units.
 # FIXME: do pattern matching for many similarly-named channels
 
 import Queue
+import re
 import sys
 import syslog
 import urllib
@@ -63,7 +64,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.10"
+VERSION = "0.11"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -309,5 +310,6 @@ class EmonCMSThread(weewx.restx.RESTThread):
             parts.append('&node=%s' % self.node)
         parts.append('&json={%s}' % ','.join(data))
         url = ''.join(parts)
-        logdbg('url: %s' % url)
+        if weewx.debug >= 2:
+            logdbg('url: %s' % re.sub(r"apikey=[^\&]*", "apikey=XXX", url))
         return url
